@@ -45,6 +45,7 @@
 
 import json
 import os
+from typing import Union
 
 from pygeometa.core import get_charstring
 from pygeometa.helpers import json_serial
@@ -65,7 +66,7 @@ class OGCAPIRecordOutputSchema(BaseOutputSchema):
 
         super().__init__('oarec-record', 'json', THISDIR)
 
-    def write(self, mcf: dict, stringify: str = True) -> str:
+    def write(self, mcf: dict, stringify: str = True) -> Union[dict, str]:
         """
         Write outputschema to JSON string buffer
 
@@ -74,7 +75,7 @@ class OGCAPIRecordOutputSchema(BaseOutputSchema):
                           else native (dict, etree)
 
 
-        :returns: MCF as a STAC item representation
+        :returns: `dict` or `str` of MCF as an OARec record representation
         """
 
         lang1 = mcf['metadata'].get('language')
@@ -103,27 +104,25 @@ class OGCAPIRecordOutputSchema(BaseOutputSchema):
                     [minx, miny]
                 ]]
             },
-            'extents': {
-                'spatial': {
-                    'bbox': [minx, miny, maxx, maxy],
-                    'crs': 'http://www.opengis.net/def/crs/OGC/1.3/CRS84'  # noqa
-                }
-            },
             'properties': {
-                'externalId': [mcf['metadata']['identifier']],
+                'identifier': mcf['metadata']['identifier'],
+                'externalId': [{
+                    'scheme': 'default',
+                    'value': mcf['metadata']['identifier']
+                }],
                 'title': title[0],
                 'description': description[0],
                 'themes': [],
+                'providers': [],
                 'language': lang1,
                 'type': mcf['metadata']['hierarchylevel'],
-                'extents': {
+                'extent': {
                     'spatial': {
-                        'bbox': [minx, miny, maxx, maxy],
+                        'bbox': [[minx, miny, maxx, maxy]],
                         'crs': 'http://www.opengis.net/def/crs/OGC/1.3/CRS84'  # noqa
                     }
-                }
+                },
             },
-            'associations': [],
             'links': []
         }
 
@@ -138,19 +137,16 @@ class OGCAPIRecordOutputSchema(BaseOutputSchema):
                 'interval': [begin, end],
                 'trs': 'http://www.opengis.net/def/uom/ISO-8601/0/Gregorian'  # noqa
             }
+            if 'resolution' in  mcf['identification']['extents']['temporal'][0]:  # noqa
+                temporal['resolution'] =  mcf['identification']['extents']['temporal'][0]['resolution']  # noqa
 
-            mcf['identification']['extents']['temporal'] = temporal
+            record['properties']['extent']['temporal'] = temporal
 
         if 'creation' in mcf['identification']['dates']:
             record['properties']['created'] = mcf['identification']['dates']['creation']  # noqa
         if 'revision' in mcf['identification']['dates']:
             record['properties']['updated'] = mcf['identification']['dates']['revision']  # noqa
 
-        organization = get_charstring(mcf['contact']['main'].get('organization'),  # noqa
-                                      lang1, lang2)
-
-        record['properties']['publisher'] = organization[0]
-
         rights = get_charstring(mcf['identification'].get('rights'),
                                 lang1, lang2)
 
@@ -166,12 +162,9 @@ class OGCAPIRecordOutputSchema(BaseOutputSchema):
             record['properties']['formats'] = list(
                 set([f[0] for f in formats]))
 
-        record['properties']['contactPoint'] = self.generate_responsible_party(
-            mcf['contact']['main'], lang1, lang2, 'pointOfContact')
-
-        if 'distribution' in mcf['contact']:
-            record['properties']['publisher'] = self.generate_responsible_party(  # noqa
-                mcf['contact']['distribution'], lang1, lang2, 'distributor')
+        for key, value in mcf['contact'].items():
+            record['properties']['providers'].append(
+                self.generate_responsible_party(value, lang1, lang2, key))
 
         for value in mcf['identification']['keywords'].values():
             theme = {'concepts': []}
@@ -194,8 +187,10 @@ class OGCAPIRecordOutputSchema(BaseOutputSchema):
 
             name = get_charstring(value.get('name'), lang1, lang2)
 
+            reltype = value.get('links') or value.get('function')
+
             link = {
-                'rel': value['function'],
+                'rel': reltype,
                 'href': value['url'],
                 'type': value['type']
             }
@@ -207,9 +202,12 @@ class OGCAPIRecordOutputSchema(BaseOutputSchema):
             if all(x in value['url'] for x in ['{', '}']):
                 link['templated'] = True
 
-            record['associations'].append(link)
+            record['links'].append(link)
 
-        return json.dumps(record, default=json_serial, indent=4)
+        if stringify:
+            return json.dumps(record, default=json_serial, indent=4)
+
+        return record
 
     def generate_responsible_party(self, contact: dict,
                                    lang1: str, lang2: str, role: str) -> dict:
@@ -243,9 +241,9 @@ class OGCAPIRecordOutputSchema(BaseOutputSchema):
         postalcode = get_charstring(contact.get('postalcode'), lang1, lang2)
         country = get_charstring(contact.get('country'), lang1, lang2)
 
-        return {
-            'individualName': contact['individualname'],
-            'organizationName': organization_name[0],
+        rp = {
+            'name': organization_name[0],
+            'individual': contact['individualname'],
             'positionName': position_name[0],
             'contactInfo': {
                 'phone': {
@@ -257,7 +255,7 @@ class OGCAPIRecordOutputSchema(BaseOutputSchema):
                 'address': {
                     'office': {
                         'deliveryPoint': address[0],
-                        'city': city,
+                        'city': city[0],
                         'administrativeArea': administrative_area[0],
                         'postalCode': postalcode[0],
                         'country': country[0]
@@ -269,7 +267,16 @@ class OGCAPIRecordOutputSchema(BaseOutputSchema):
                 'hoursOfService': hours_of_service[0],
                 'contactInstructions': contact_instructions[0]
             },
-            'role': {
+            'roles': [{
                 'name': role
-            }
+            }]
         }
+
+        if 'url' in contact:
+            rp['contactInfo']['url'] = {
+                'rel': 'canonical',
+                'type': 'text/html',
+                'href': contact['url']
+            }
+
+        return rp
